@@ -1,6 +1,6 @@
 ;;; hib-kbd.el --- Implicit button type for key sequences delimited with {}.
 
-;; Copyright (C) 1991-1995 Free Software Foundation, Inc.
+;; Copyright (C) 1991-1995, 2008 Free Software Foundation, Inc.
 ;; Developed with support from Motorola Inc.
 
 ;; Author: Bob Weiner, Brown U.
@@ -128,7 +128,7 @@ With optional FULL, displays full documentation for command."
 	  )
     (while (string-match "\\`\\(C-u\\|M-\\)\\(-?[0-9]+\\)" norm-key-seq)
       (setq current-prefix-arg
-	    (string-to-int (substring norm-key-seq (match-beginning 2)
+	    (string-to-number (substring norm-key-seq (match-beginning 2)
 				      (match-end 2)))
 	    norm-key-seq (substring norm-key-seq (match-end 0))))
     (let (arg-val)
