@@ -1,6 +1,6 @@
 ;;; klabel.el --- Display label handling for koutlines.
 
-;; Copyright (C)  Free Software Foundation, Inc.
+;; Copyright (C) 2008 Free Software Foundation, Inc.
 ;; Developed with support from Motorola Inc.
 
 ;; Author: Bob Weiner, Brown U.
@@ -230,7 +230,7 @@ First visible outline cell is level 1."
 	((string-match "[0-9]+$" label)
 	 (concat (substring label 0 (match-beginning 0))
 		 (int-to-string
-		  (1+ (string-to-int (substring label (match-beginning 0)))))))
+		  (1+ (string-to-number (substring label (match-beginning 0)))))))
 	(t (error "(klabel:increment-legal): Invalid label, '%s'" label))))
 
 (defun klabel:level-legal (label)
@@ -310,7 +310,7 @@ With optional CHILD-P, return label for first child cell of PREV-LABEL cell."
 	(concat prev-label ".1"))
     (let* ((last-part (string-match "[0-9]+$" prev-label))
 	   (partial-legal (substring prev-label last-part))
-	   (next (kotl-label:create (1+ (string-to-int partial-legal)))))
+	   (next (kotl-label:create (1+ (string-to-number partial-legal)))))
       (if (equal last-part prev-label)
 	  next
 	(concat (substring prev-label 0 last-part) next)))))
@@ -417,7 +417,7 @@ and the start of its contents."
 				      0 (- (length label-suffix)))
 	      suffix-function (if (kotl-label:integer-p label-suffix)
 				  (progn (setq suffix-val
-					       (string-to-int label-suffix))
+					       (string-to-number label-suffix))
 					 'int-to-string)
 				(setq suffix-val
 				      (kotl-label:alpha-to-int label-suffix))
@@ -465,7 +465,7 @@ and the start of its contents."
 	(setq label-suffix (klabel:to-kotl-label current-cell-label)
 	      label-prefix (substring current-cell-label
 				      0 (- (length label-suffix)))
-	      suffix-val (string-to-int label-suffix)))
+	      suffix-val (string-to-number label-suffix)))
     (while current-cell-label
       ;; Set current cell's label.
       (klabel:set current-cell-label label-sep-len)
@@ -510,7 +510,7 @@ and the start of its contents."
 	(setq label-suffix current-cell-label
 	      suffix-function (if (kotl-label:integer-p label-suffix)
 				  (progn (setq suffix-val
-					       (string-to-int label-suffix))
+					       (string-to-number label-suffix))
 					 'int-to-string)
 				(setq suffix-val
 				      (kotl-label:alpha-to-int label-suffix))
@@ -630,7 +630,7 @@ is signaled."
 	    (kotl-label:alpha-p label))
 	;; Test if trying to decrement below 1 or a.
 	(if int-p
-	    (progn (setq int-p (string-to-int label))
+	    (progn (setq int-p (string-to-number label))
 		   (if (> (setq val (+ int-p n)) 0)
 		       (kotl-label:create val)
 		     (error "(kotl-label:increment): Decrement of '%s' by '%d' is less than 1." label n)))
@@ -650,7 +650,7 @@ For example, z would become aa, and aa would become bb.  LABEL must be >= a."
 (defun kotl-label:increment-int (int-string)
   "Return INT-STRING label incremented by 1.
 For example, \"14\" would become \"15\"."
-  (int-to-string (1+ (string-to-int int-string))))
+  (int-to-string (1+ (string-to-number int-string))))
 
 (defun kotl-label:integer-p (label)
   "Return LABEL iff LABEL is composed of all digits, else return nil."
@@ -663,7 +663,7 @@ For example, \"14\" would become \"15\"."
 (defun kotl-label:int-to-alpha (n)
   "Return alphabetic representation of N as a string.
 N may be an integer or a string containing an integer."
-  (if (stringp n) (setq n (string-to-int n)))
+  (if (stringp n) (setq n (string-to-number n)))
   (let ((lbl "") pow26 exp26 quotient remainder)
     (if (= n 0)
 	""
